@@ -1,6 +1,8 @@
+import doctest
 import publicsuffix
 import unittest
 import sys
+import warnings
 
 if sys.version < '3':
 	import codecs
@@ -59,9 +61,21 @@ class TestPublicSuffix(unittest.TestCase):
 		self.assertEqual(psl.get_public_suffix(u("a.example.\u0440\u0444")), u("example.\u0440\u0444"))
 		self.assertEqual(psl.get_public_suffix(u("a.a.example.\u0440\u0444")), u("example.\u0440\u0444"))
 
+	def _get_builtin_psl(self):
+
+		with warnings.catch_warnings(record=True) as w:
+			warnings.simplefilter("always")
+			psl = publicsuffix.PublicSuffixList()
+
+		self.assertEqual(len(w), 1)
+		self.assertTrue(issubclass(w[0].category, DeprecationWarning))
+		self.assertTrue("deprecated" in str(w[0].message))
+
+		return psl
+
 	def test_publicsuffix_org_list_test(self):
 
-		psl = publicsuffix.PublicSuffixList()
+		psl = self._get_builtin_psl()
 
 		def checkPublicSuffix(a, b):
 			self.assertEqual(psl.get_public_suffix(a), b)
@@ -128,3 +142,25 @@ class TestPublicSuffix(unittest.TestCase):
 		checkPublicSuffix('k12.ak.us', 'k12.ak.us');
 		checkPublicSuffix('test.k12.ak.us', 'test.k12.ak.us');
 		checkPublicSuffix('www.test.k12.ak.us', 'test.k12.ak.us');
+
+	def test_publicsuffix_org_list_unicode(self):
+
+		psl = self._get_builtin_psl()
+
+		def checkPublicSuffix(a, b):
+			self.assertEqual(psl.get_public_suffix(a), b)
+
+		checkPublicSuffix(u('www.\u9999\u6e2f'), u('www.\u9999\u6e2f'))
+
+	def test_fetch(self):
+		f = publicsuffix.fetch()
+		psl = publicsuffix.PublicSuffixList(f)
+
+		self.assertEqual(psl.get_public_suffix("www.example.com"), "example.com")
+		self.assertEqual(psl.get_public_suffix(u('www.\u9999\u6e2f')), u('www.\u9999\u6e2f'))
+
+def additional_tests():
+	return doctest.DocFileSuite("README.rst")
+
+if __name__ == '__main__':
+	unittest.main('tests')
